<?php
/**
 * @author Victor Dubiniuk <dubiniuk@owncloud.com>
 *
 * @copyright Copyright (c) 2015, ownCloud, Inc.
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License, version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License, version 3,
 * along with this program.  If not, see <http://www.gnu.org/licenses/>
 *
 */

namespace Owncloud\Updater\Command;

use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;

class EnableNotShippedAppsCommand extends Command {

	protected function configure(){
		$this
				->setName('upgrade:enableNotShippedApps')
				->setDescription('try reenable and upgrade 3rdparty/non shipped apps. (one app after another)')
		;
	}

	protected function execute(InputInterface $input, OutputInterface $output){
		/** @var \Owncloud\Updater\Utils\Locator $locator */
		$locator = $this->container['utils.locator'];
		/** @var \Owncloud\Updater\Utils\Checkpoint $checkpoint */
		$checkpoint = $this->container['utils.checkpoint'];
		/** @var \Owncloud\Updater\Utils\FilesystemHelper $fsHelper */
		$fsHelper = $this->container['utils.filesystemhelper'];

		$registry = $this->container['utils.registry'];

		$notShippedApps = $registry->get('notShippedApps');
		$notShippedApps = is_array($notShippedApps) ? $notShippedApps : [];

		$lastCheckpointId = $checkpoint->getLastCheckpointId();
		$lastCheckpointPath = $checkpoint->getCheckpointPath($lastCheckpointId);
		if ($lastCheckpointId){
			$oldSourcesDir = $locator->getOwnCloudRootPath();
			foreach ($notShippedApps as $notShippedApp) {
				$fsHelper->copyr($lastCheckpointPath . '/apps/' . $notShippedApp, $oldSourcesDir . '/apps/' . $notShippedApp, false);
			}
		}

		/** @var \Owncloud\Updater\Utils\AppManager $appManager */
		$appManager = $registry->get('appManager');
		if (!is_null($appManager)){
			$appManager->reenableNotShippedApps($output);
		}
	}
}
